﻿#define TEST_BIKE_COMPUTER

using System;
using System.Threading;
using Ws.Services;
using Ws.Services.Binding;
using System.Ext;
using System.Net;
using System.Xml;
using tempuri.org;

namespace Microsoft.SPOT.Sample
{
    public class MFSimpleServiceClient
    {
        public static void Main()
        {
            // Turn console messages on
            Console.Verbose = true;

            // Create a test application thread
            TestApplication testApp = new TestApplication();
            Thread testAppThread = new Thread(new ThreadStart(testApp.Run));
            testAppThread.Start();

            System.Ext.Console.Write("Application started...");
        }
    }

    /// <summary>
    /// SimpleService test application class.
    /// </summary>
    public class TestApplication
    {
#if TEST_BIKE_COMPUTER
        IBikeComputerServiceClientProxy m_proxy;
#else
        IDataAccessServiceClientProxy m_proxy;
#endif

        public void Run()
        {
            
            TestMtomService();
        }

        private void TestMtomService()
        {
            try
            {
#if TEST_BIKE_COMPUTER
                WS2007HttpBinding binding = new WS2007HttpBinding(
                    new HttpTransportBindingConfig(new Uri("http://netmfbikecomputerservice.cloudapp.net/BikeComputerService.svc")));

                m_proxy = new IBikeComputerServiceClientProxy(binding, new ProtocolVersion11());

                UploadBikeComputerData upload = new UploadBikeComputerData();
                upload.rideData = new schemas.datacontract.org.BikeComputerServiceWebRole.BikeComputerData();
                upload.rideData.AverageCadence = 1.2f;
                upload.rideData.AverageIncline = 3.4f;
                upload.rideData.AverageSpeed = 18.8f;
                upload.rideData.AverageTemperature = 65.3f;
                upload.rideData.Date = DateTime.UtcNow;
                upload.rideData.Distance = 34.22f;
                upload.rideData.RidingTime = new TimeSpan(2, 3, 5);
                upload.rideData.StartTime = new TimeSpan(1, 0, 0);
                upload.rideData.TemperatureIsInCelcius = false;
                upload.rideData.TotalTime = new TimeSpan(3, 4, 5);

                m_proxy.UploadBikeComputerData(upload);

                GetLastComputerData req = new GetLastComputerData();

                GetLastComputerDataResponse back = m_proxy.GetLastComputerData(req);

                if (back.GetLastComputerDataResult.AverageCadence == upload.rideData.AverageCadence)
                {
                    Debug.Print("YEAH!");
                }
#else
                WS2007HttpBinding binding = new WS2007HttpBinding(
                    new HttpTransportBindingConfig(new Uri("http://localhost:51026/Service1.svc")));

                m_proxy = new IDataAccessServiceClientProxy(binding, new ProtocolVersion11());

                SetData req = new SetData();
                req.value = System.Text.UTF8Encoding.UTF8.GetBytes(
@"A bedtime story is a traditional form of storytelling, where a story is told to a child at bedtime to prepare them for sleep.
Bedtime stories have many advantages, for parents/adults and children alike. The fixed routine of a bedtime story before sleeping has a relaxing effect, and the soothing voice of a person telling a story makes the child fall asleep more easily. The emotional aspect creates a bond between the storyteller and the listener, often a parent and child.
Bedtime stories can be read from a book, or rather, fictional stories made up by the storyteller. The stories are mostly rather short, between one and five minutes, and have a happy ending. A different form of bedtime reading is using longer stories, but dividing them up, thus creating cliffhangers. Children will look forward to their bedtime story, and a fixed routine is installed.
");
                m_proxy.SetData(req);

                GetData req2 = new GetData();
                req2.value = 3;

                GetDataResponse resp = m_proxy.GetData(req2);

                Debug.Print(new string(System.Text.UTF8Encoding.UTF8.GetChars(resp.GetDataResult)));


                SetFileInfo sfi = new SetFileInfo();

                sfi.files = new schemas.datacontract.org.WcfMtomService.ArrayOfFileInfo();

                sfi.files.FileInfo = new schemas.datacontract.org.WcfMtomService.FileInfo[2];

                sfi.files.FileInfo[0] = new schemas.datacontract.org.WcfMtomService.FileInfo();
                sfi.files.FileInfo[0].Name = "MyBook";
                sfi.files.FileInfo[0].Size = 340;
                sfi.files.FileInfo[1] = new schemas.datacontract.org.WcfMtomService.FileInfo();
                sfi.files.FileInfo[1].Name = "MyBook2";
                sfi.files.FileInfo[1].Size = 341;

                m_proxy.SetFileInfo(sfi);
#endif

            }
            catch (System.IO.IOException)
            {
                // Is the web service down???
                Debug.Print("Warning: could not connect to stocks web service");
            }
            finally
            {
                if (m_proxy != null) m_proxy.Dispose();
            }
        }
    }
}
